@@ -22,6 +22,8 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/OneOfMany.h>
+
 #include <Lum/ButtonRow.h>
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
@@ -41,16 +43,15 @@ GameStartDialog::GameStartDialog(size_t points, size_t player)
   Observe(this->points);
 }
 
-void GameStartDialog::PreInit()
+Lum::Object* GameStartDialog::GetContent()
 {
   Lum::TextEditCombo         *pointsCombo;
-  Lum::IndexCombo            *playerCombo;
   Lum::Label                 *label;
   Lum::Panel                 *vert;
   Lum::Model::StringTableRef pointsList;
   Lum::Model::StringTableRef engines;
 
-  vert=new Lum::VPanel();
+  vert=Lum::VPanel::Create(true,true);
 
   label=Lum::Label::Create(true,false);
 
@@ -71,18 +72,20 @@ void GameStartDialog::PreInit()
   engines->Append(_(L"GAME_START_GREEDY",L"Mr. Mc Greedy"));
   engines->Append(_(L"GAME_START_RANDOM",L"Mr. Random"));
 
-  playerCombo=new Lum::IndexCombo();
-  playerCombo->SetTableModel(engines);
-  playerCombo->SetModel(player);
-  label->AddLabel(_(L"GAME_START_LABEL_PLAYER",L"Computer opponent:"),playerCombo);
+  Lum::Def::OneOfMany playerDef(Lum::Def::Desc(L"Player"),
+                                player,engines);
+
+  label->AddLabel(_(L"GAME_START_LABEL_PLAYER",L"Computer opponent:"),
+                  Lum::OS::display->GetBehaviour()->GetOneOfManyControl(playerDef,true,false));
 
   vert->Add(label);
-  vert->AddSpace();
-  vert->Add(Lum::ButtonRow::CreateOkCancel(commitAction,GetClosedAction(),true,false));
 
-  SetMain(vert);
+  return vert;
+}
 
-  Dialog::PreInit();
+void GameStartDialog::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
+{
+  CreateActionInfosOkCancel(actions,commitAction,GetClosedAction());
 }
 
 void GameStartDialog::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -105,7 +108,7 @@ void GameStartDialog::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg
     }
   }
 
-  Dialog::Resync(model,msg);
+  ActionDialog::Resync(model,msg);
 }
 
 bool GameStartDialog::GetSuccess() const
